@@ -21,9 +21,13 @@ use Moose;
 use MooseX::Types::Moose ':all';
 use MooseX::Types::Path::Class ':all';
 use namespace::autoclean;
+use File::Copy 'cp';
 use Path::Class;
 
+use autodie 'system';
+
 extends 'MooseX::App::Cmd::Command';
+with 'Fedora::App::MaintainerTools::Role::Logger';
 with 'Fedora::App::MaintainerTools::Role::Template';
 with 'Fedora::App::MaintainerTools::Role::SpecUtils';
 
@@ -33,17 +37,16 @@ my @CLASSES = qw{
     Fedora::App::MaintainerTools::SpecData::New
 };
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 has package => (is => 'ro', isa => Bool, default => 0);
 
 sub command_names { 'new-spec' }
-sub _specdata_base_class { 'Fedora::App::MaintainerTools::SpecData::New' }
 
-sub run {
+sub execute {
     my ($self, $opt, $args) = @_;
 
-    $self->app->log->info('Beginning new-spec run.');
+    $self->log->info('Beginning new-spec run.');
 
     Class::MOP::load_class($_) for @CLASSES;
 
@@ -52,12 +55,13 @@ sub run {
         # FIXME this might not be the best approach.
         $pkg =~ s/::/-/g;
 
-        my $data = $self->_specdata_class->new(dist => $pkg);
+        my $data = $self->_new_spec_class->new(dist => $pkg);
             #Fedora::App::MaintainerTools::SpecData::New->new(dist => $pkg);
 
-        print $data->output;
-
-        $data->build_srpm;
+        #print $data->output;
+        #$data->build_srpm;
+        $self->build_srpm($data);
+        $self->build_rpm($data);
     }
 
     return;
